@@ -19,7 +19,7 @@ def get_template_path(template_name):
     script_path = os.path.abspath(__file__)
     module_path = os.path.dirname(script_path)
     project_path = os.path.dirname(module_path)
-    cookiecutters_path = os.path.join(project_path, "cookiecutters")
+    cookiecutters_path = os.path.join(project_path, "templates")
     return os.path.join(cookiecutters_path, template_name)
     
 
